@@ -36,35 +36,11 @@
 # SPDX-License-Identifier: Apache-2.0
 # ============================================================================
 #
-from dataclasses  import make_dataclass
-from os           import environ
+from pyVersioning.CIService import CIService
 
 
-class GitHub:
-	def getEnvironment(self):
-		env = environ
-		filteredEnv = {key:value for (key,value) in environ if key.startswith("GITHUB_") and not key.endswith("_TOKEN")}
-
-		# manually add some variables
-		for key in ['CI']:
-			try:
-				filteredEnv[key] = env[key]
-			except:
-				pass
-
-		# manually delete some variables
-		for key in ['CI_JOB_TOKEN']:
-			try:
-				del filteredEnv[key]
-			except:
-				pass
-
-		Environment = make_dataclass(
-			"Environment",
-			[(name, str) for name in env.keys()],
-			namespace={
-				'as_dict': lambda self: env
-			}
-		)
-
-		return Environment(**env)
+class GitHub(CIService):
+	ENV_INCLUDE_FILTER =  ("GITHUB_")
+	ENV_EXCLUDE_FILTER =  ("_TOKEN")
+	ENV_INCLUDES =        ['CI']
+	ENV_EXCLUDES =        []
